
/* Chrysalide - Outil d'analyse de fichiers binaires
 * bytes.h - prototypes pour la sauvegarde de correspondances avec des suites d'octets identifiées
 *
 * Copyright (C) 2022 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _ANALYSIS_SCAN_MATCHES_BYTES_H
#define _ANALYSIS_SCAN_MATCHES_BYTES_H


#include <glib-object.h>


#include "area.h"
#include "../context.h"
#include "../matches.h"



/* -------------------- CONSERVATION DE CORRESPONDANCES ETABLIES -------------------- */


#define G_TYPE_SCAN_BYTES_MATCHES            g_scan_bytes_matches_get_type()
#define G_SCAN_BYTES_MATCHES(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), G_TYPE_SCAN_BYTES_MATCHES, GScanBytesMatches))
#define G_IS_SCAN_BYTES_MATCHES(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), G_TYPE_SCAN_BYTES_MATCHES))
#define G_SCAN_BYTES_MATCHES_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), G_TYPE_SCAN_BYTES_MATCHES, GScanBytesMatchesClass))
#define G_IS_SCAN_BYTES_MATCHES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), G_TYPE_SCAN_BYTES_MATCHES))
#define G_SCAN_BYTES_MATCHES_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_SCAN_BYTES_MATCHES, GScanBytesMatchesClass))


/* Correspondances trouvées avec des suite d'octets (instance) */
typedef struct _GScanBytesMatches GScanBytesMatches;

/* Correspondances trouvées avec des suite d'octets (classe) */
typedef struct _GScanBytesMatchesClass GScanBytesMatchesClass;


/* Indique le type défini pour une série de correspondances d'octets identifiées. */
GType g_scan_bytes_matches_get_type(void);

/* Crée un suivi pour série de correspondances avec des octets. */
GScanMatches *g_scan_bytes_matches_new(GSearchPattern *, GScanContext *);

/* Fournit le contexte du scan associé aux correspondances. */
GScanContext *g_scan_bytes_matches_get_context(const GScanBytesMatches *);

/* Intègre une liste de correspondances vérifiées. */
void g_scan_bytes_matches_set_list(GScanBytesMatches *, match_area_t *, size_t);

/* Indique le nombre de correspondances pour une définition. */
size_t g_scan_bytes_matches_count(const GScanBytesMatches *);

/* Fournit les informations relatives à une correspondance. */
const match_area_t *g_scan_bytes_matches_get(const GScanBytesMatches *, size_t);

/* Indique la localisation d'une correspondance établie. */
phys_t g_scan_bytes_matches_get_location(const GScanBytesMatches *, size_t, phys_t *, phys_t *);

/* Retrouve l'origine d'une correspondance à partir d'un indice. */
char *g_scan_bytes_matches_get_modifier_path(const GScanBytesMatches *);



#endif  /* _ANALYSIS_SCAN_MATCHES_BYTES_H */
